aboutsummaryrefslogtreecommitdiffstats
path: root/version_info.c
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-22 08:14:01 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-22 08:14:01 +0000
commitf0b33a47893e76488561e57d6c2dce07a1295d4b (patch)
tree94060daf713860116bedfbe9673d9a057b4a0824 /version_info.c
parent92552c2d765dcf89883392fcd11556d54f2843e5 (diff)
ethereal->wireshark updates
svn path=/trunk/; revision=18206
Diffstat (limited to 'version_info.c')
-rw-r--r--version_info.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/version_info.c b/version_info.c
index 6b508b9e79..b25e3905df 100644
--- a/version_info.c
+++ b/version_info.c
@@ -1,5 +1,5 @@
/* version_info.c
* Routines to report version information for stuff used by Ethereal
*
* $Id$
*
@@ -213,7 +213,7 @@ get_compiled_version_info(GString *str)
#ifndef HAVE_LIBPCRE
break_point = str->len - 1;
g_string_append(str,
- "\nNOTE: this build doesn't support the \"matches\" operator for Ethereal filter"
+ "\nNOTE: this build doesn't support the \"matches\" operator for Wireshark filter"
"\nsyntax.");
do_word_wrap(str, break_point);
#endif /* HAVE_LIBPCRE */
@@ -1,5 +1,5 @@
/* version_info.c
- * Routines to report version information for stuff used by Ethereal
+ * Routines to report version information for stuff used by Wireshark
*
* $Id$